@@ -4,30 +4,10 @@ from .common import *
 from .shared import (Parameter, do_no_override, get_endvalue, get_expvalue,
                      get_subvalue, auto_get_props, get_condition, add_obj)
 from .route53 import R53_RecordSetRDS
+from .securitygroup import SG_SecurityGroupService
 
 
 class RDSDBInstance(rds.DBInstance):
-    def __init__(self, title, **kwargs):
-        super().__init__(title, **kwargs)
-
-        self.AllocatedStorage = get_endvalue('AllocatedStorage')
-        self.AllowMajorVersionUpgrade = 'True'
-        self.DBInstanceClass = get_endvalue('DBInstanceClass')
-        self.DBName = get_endvalue(
-            'DBName', nocondition='DBInstanceSkipProperties')
-        self.Engine = get_endvalue('Engine')
-        self.EngineVersion = get_endvalue('EngineVersion')
-        self.MasterUsername = get_endvalue(
-            'MasterUsername', nocondition='DBInstanceSkipProperties')
-        self.MasterUserPassword = get_endvalue(
-            'MasterUserPassword', nocondition='DBInstanceSkipProperties')
-        self.MultiAZ = get_endvalue('MultiAZ')
-        self.DBParameterGroupName = Ref('DBParameterGroup1')
-        self.SourceDBInstanceIdentifier = get_endvalue(
-            'SourceDBInstanceIdentifier', condition=True)
-        self.StorageType = get_endvalue('StorageType')
-        self.VPCSecurityGroups = [Ref('SecurityGroupRDS')]
-
     def validate(self):
         if 'DBSnapshotIdentifier' not in self.properties:
             if 'Engine' not in self.properties:
@@ -101,26 +81,19 @@ class RDSDBInstance(rds.DBInstance):
         return True
 
 
-class RDSDBInstancePublic(RDSDBInstance):
-    def __init__(self, title, **kwargs):
-        super().__init__(title, **kwargs)
-
-        self.DBSubnetGroupName = get_expvalue('DBSubnetGroupPublic')
-        self.PubliclyAccessible = 'True'
-
-
-class RDSDBInstancePrivate(RDSDBInstance):
-    def __init__(self, title, **kwargs):
-        super().__init__(title, **kwargs)
-
-        self.DBSubnetGroupName = get_expvalue('DBSubnetGroupPrivate')
-        self.PubliclyAccessible = 'False'
-
-
 class RDSDBParameterGroup(rds.DBParameterGroup):
-    def setup(self):
+    def __init__(self, title, dbinstance, **kwargs):
+        super().__init__(title, **kwargs)
         self.Description = Sub('MYSQL %s - ${AWS::StackName}' % self.title)
-        self.Family = get_subvalue('mysql${1M}', 'EngineVersion')
+        self.Family = Sub('${Engine}${EngineVersion}', **{
+            'Engine': get_endvalue(f'{dbinstance}Engine'),
+            'EngineVersion': Join('.', [
+                Select(0,
+                       Split('.', get_endvalue(f'{dbinstance}EngineVersion'))),
+                Select(1,
+                       Split('.', get_endvalue(f'{dbinstance}EngineVersion'))),
+            ])
+        })
 
 
 class RDSDBSubnetGroupPrivate(rds.DBSubnetGroup):
@@ -134,62 +107,71 @@ class RDSDBSubnetGroupPublic(rds.DBSubnetGroup):
         self.DBSubnetGroupDescription = Sub('${EnvShort}-Public')
         self.SubnetIds = Split(',', get_expvalue('SubnetsPublic'))
 
-# #################################
-# ### START STACK INFRA CLASSES ###
-# #################################
 
+def RDS_DB(key):
+    for n, v in getattr(cfg, key).items():
+        mapname = f'{key}{n}'
 
-class RDS_ParameterGroups(object):
-    def __init__(self, key):
-        for n, v in getattr(cfg, key).items():
-            resname = f'{key}{n}'
-            # Resources
-            r_PG = RDSDBParameterGroup(resname)
-            r_PG.setup()
-            r_PG.Parameters = v
+        if not v['IBOXENABLED']:
+            continue
 
-            add_obj(r_PG)
+        try:
+            resname = v['IBOXRESNAME']
+        except Exception:
+            resname = mapname
 
+        # resources
+        r_DB = RDSDBInstance(mapname)
+        auto_get_props(r_DB, mapname=mapname)
+        # trick to keep current in use resname obj.title - need to be
+        # executed after invoking auto_get_props
+        r_DB.title = resname
+        # trick - when providing DBSnapshotIdentifier
+        # or SourceDBInstanceIdentifier some props must not exists
+        for m in ['DBName',
+                  'MasterUsername',
+                  'MasterUserPassword']:
+            setattr(r_DB, m, If(
+                f'{mapname}DBInstanceSkipProperties',
+                Ref('AWS::NoValue'),
+                getattr(r_DB, m)))
+        for m in ['SourceDBInstanceIdentifier', 'DBSnapshotIdentifier']:
+            setattr(r_DB, m, If(
+                f'{mapname}{m}',
+                getattr(r_DB, m),
+                Ref('AWS::NoValue')))
 
-class RDS_DB(object):
-    def __init__(self, key):
-        # Resources
-        if cfg.RDSScheme == 'External':
-            R_DB = RDSDBInstancePublic('DBInstance')
-        if cfg.RDSScheme == 'Internal':
-            R_DB = RDSDBInstancePrivate('DBInstance')
-
-        R53_RecordSetRDS()
+        R53_RecordSetRDS(resname)
+        SG_SecurityGroupService(mapname)
+        # trick fixed name to avoid reboot for now
+        # best way should be to use a name like DBParameterGroup{Engine}
+        r_PG = RDSDBParameterGroup('DBParameterGroup1', mapname)
+        r_PG.Parameters = cfg.DBParameterGroup1
 
         add_obj([
-            R_DB,
-        ])
+            r_DB,
+            r_PG])
 
 
-class RDS_SubnetGroups(object):
-    def __init__(self, key):
-        # Resources
-        R_Private = RDSDBSubnetGroupPrivate('DBSubnetGroupPrivate')
-        R_Private.setup()
+def RDS_SubnetGroups(key):
+    # Resources
+    R_Private = RDSDBSubnetGroupPrivate('DBSubnetGroupPrivate')
+    R_Private.setup()
 
-        R_Public = RDSDBSubnetGroupPublic('DBSubnetGroupPublic')
-        R_Public.setup()
+    R_Public = RDSDBSubnetGroupPublic('DBSubnetGroupPublic')
+    R_Public.setup()
 
-        add_obj([
-            R_Private,
-            R_Public,
-        ])
+    # Outputs
+    O_Private = Output('DBSubnetGroupPrivate')
+    O_Private.Value = Ref('DBSubnetGroupPrivate')
+    O_Private.Export = Export('DBSubnetGroupPrivate')
 
-        # Outputs
-        O_Private = Output('DBSubnetGroupPrivate')
-        O_Private.Value = Ref('DBSubnetGroupPrivate')
-        O_Private.Export = Export('DBSubnetGroupPrivate')
+    O_Public = Output('DBSubnetGroupPublic')
+    O_Public.Value = Ref('DBSubnetGroupPublic')
+    O_Public.Export = Export('DBSubnetGroupPublic')
 
-        O_Public = Output('DBSubnetGroupPublic')
-        O_Public.Value = Ref('DBSubnetGroupPublic')
-        O_Public.Export = Export('DBSubnetGroupPublic')
-
-        add_obj([
-            O_Private,
-            O_Public,
-        ])
+    add_obj([
+        R_Private,
+        R_Public,
+        O_Private,
+        O_Public])
